<?php
/**
 * Created by PhpStorm.
 * User: mojtaba
 * Date: 9/16/18
 * Time: 10:29 PM
 */

class Newspapik_Theme_Options {
	/**
	 * The single instance of the class.
	 *
	 * @var Newspapik_Theme_Options
	 */
	protected static $_instance = null;

	private $categories;

	/**
	 * Newspapik constructor.
	 */
	public function __construct() {
		$categories         = get_categories( array(
			'orderby'    => 'name',
			'hide_empty' => false
		) );
		$categories_choices = [];
		foreach ( $categories as $category ) {
			$categories_choices[ $category->term_id ] = $category->name;
		}
		$this->categories = $categories_choices;
		add_action( 'customize_register', array( $this, 'customize_register' ) );
	}

	public function customize_register( WP_Customize_Manager $wp_customize ) {

		$wp_customize->add_section( 'newspapik_slider', array(
			'title'       => __( 'Featured post slider', 'newspapik' ),
			'description' => __( 'Display posts from selected categories below site header as featured posts', 'newspapik' ),
			'priority'    => 30
		) );

		// Slider status
		$wp_customize->add_setting( 'newspapik_slider_status', array(
			'default'   => true,
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'status', array(
			'label'    => __( 'Active featured post slider', 'newspapik' ),
			'section'  => 'newspapik_slider',
			'settings' => 'newspapik_slider_status',
			'type'     => 'checkbox',
		) );

		// Slider title
		$wp_customize->add_setting( 'newspapik_slider_title', array(
			'default'   => __( 'Featured Posts', 'newspapik' ),
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'title', array(
			'label'    => __( 'Title', 'newspapik' ),
			'section'  => 'newspapik_slider',
			'settings' => 'newspapik_slider_title',
			'type'     => 'text',
		) );

		// Slider category
		$wp_customize->add_setting( 'newspapik_slider_categories', array(
			'default'           => 1,
			'transport'         => 'refresh',
			'sanitize_callback' => array( $this, 'sanitize_categories' )

		) );
		$wp_customize->add_control( new Newspapik_Customize_Control_Multiple_Select ( $wp_customize, 'categories', array(
			'settings' => 'newspapik_slider_categories',
			'label'    => __( 'Categories', 'newspapik' ),
			'section'  => 'newspapik_slider',
			'type'     => 'multiple-select',
			'choices'  => $this->categories
		) ) );

		// Slider number of posts
		$wp_customize->add_setting( 'newspapik_slider_number_of_posts', array(
			'default'   => 4,
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'number_of_posts', array(
			'label'    => __( 'Number of posts', 'newspapik' ),
			'section'  => 'newspapik_slider',
			'settings' => 'newspapik_slider_number_of_posts',
			'type'     => 'text',
		) );
		// Slider number of posts
		$wp_customize->add_setting( 'newspapik_slider_number_of_posts_slide', array(
			'default'   => 2,
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'number_of_posts_slide', array(
			'label'    => __( 'Number of posts in each slide', 'newspapik' ),
			'section'  => 'newspapik_slider',
			'settings' => 'newspapik_slider_number_of_posts_slide',
			'type'     => 'text',
		) );


		/* Home page settings */

		$wp_customize->add_setting( 'newspapik_home_page_type', array(
			'default'   => 'latest-posts',
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'home_page_type', array(
			'label'    => __( 'Display type', 'newspapik' ),
			'section'  => 'static_front_page',
			'settings' => 'newspapik_home_page_type',
			'type'     => 'select',
			'choices'  => array(
				'latest-posts'   => __( 'Latest posts', 'newspapik' ),
				'category-posts' => __( 'Categories posts slider', 'newspapik' ),
			)
		) );

		$wp_customize->add_setting( 'newspapik_home_category_posts_categories', array(
			'default'           => array( 1 ),
			'transport'         => 'refresh',
			'sanitize_callback' => array( $this, 'sanitize_categories' )

		) );
		$wp_customize->add_control( new Newspapik_Customize_Control_Multiple_Select ( $wp_customize, 'home_categories', array(
			'settings'    => 'newspapik_home_category_posts_categories',
			'label'       => __( 'Categories', 'newspapik' ),
			'description' => __( 'Available if display type is "Categories posts slider"', 'newspapik' ),
			'section'     => 'static_front_page',
			'type'        => 'multiple-select',
			'choices'     => $this->categories,
		) ) );

		/* Footer settings */
		$wp_customize->add_section( 'newspapik_footer', array(
			'title'    => __( 'Footer', 'newspapik' ),
			'priority' => 200
		) );


		foreach ( self::get_social_icons() as $id => $social_icon ) {
			$wp_customize->add_setting( 'newspapik_socials_' . $id, array(
				'default'   => $social_icon['default'],
				'transport' => 'refresh',
				'sanitize_callback'  => 'esc_attr',
			) );
			$wp_customize->add_control( 'newspapik_socials_icon_' . $id, array(
				'label'       => $social_icon['title'],
				'description' => $social_icon['description'],
				'section'     => 'newspapik_footer',
				'settings'    => 'newspapik_socials_' . $id,
				'type'        => 'text',
			) );
		}


		// Single page options
		$wp_customize->add_section( 'newspapik_single_page', array(
			'title'       => __( 'Post Single Page Settings', 'newspapik' ),
			'priority'    => 180
		) );

		// Thumbnail status
		$wp_customize->add_setting( 'newspapik_thumbnail_status', array(
			'default'   => true,
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'thumbnail_status', array(
			'label'    => __( 'Display Thumbnail', 'newspapik' ),
			'section'  => 'newspapik_single_page',
			'settings' => 'newspapik_thumbnail_status',
			'type'     => 'checkbox',
		) );
		// Thumbnail status
		$wp_customize->add_setting( 'newspapik_related_posts_status', array(
			'default'   => true,
			'transport' => 'refresh',
			'sanitize_callback'  => 'esc_attr',
		) );
		$wp_customize->add_control( 'related_status', array(
			'label'    => __( 'Display Related Posts', 'newspapik' ),
			'section'  => 'newspapik_single_page',
			'settings' => 'newspapik_related_posts_status',
			'type'     => 'checkbox',
		) );
	}

	public static function get_social_icons() {
		return array(
			'behance'     => array(
				'title'       => __( 'Behance', 'newspapik' ),
				'description' => 'https://behance.net/YOURUSERNAME',
				'default'     => '',
			),
			'dribble'     => array(
				'title'       => __( 'Dribble', 'newspapik' ),
				'description' => 'https://dribbble.com/YOURUSERNAME',
				'default'     => '',
			),
			'facebook'    => array(
				'title'       => __( 'Facebook', 'newspapik' ),
				'description' => 'https://facebook.com/YOURUSERNAME',
				'default'     => '',
			),
			'google-plus' => array(
				'title'       => __( 'Google plus', 'newspapik' ),
				'description' => 'https://plus.google.com/YOURID/posts',
				'default'     => '',
			),
			'instagram'   => array(
				'title'       => __( 'Instagram', 'newspapik' ),
				'description' => 'https://instagram.com/YOURUSERNAME',
				'default'     => '',
			),
			'linkedin'    => array(
				'title'       => __( 'Linkedin', 'newspapik' ),
				'description' => 'https://www.linkedin.com/in/YOURUSERNAME',
				'default'     => '',
			),
			'rss'         => array(
				'title'       => __( 'RSS', 'newspapik' ),
				'description' => 'https://behance.net/YOURUSERNAME',
				'default'     => get_feed_link(),
			),
			'twitter'     => array(
				'title'       => __( 'Twitter', 'newspapik' ),
				'description' => 'https://twitter.com/YOURUSERNAME',
				'default'     => '',
			),
			'youtube'     => array(
				'title'       => __( 'Youtube', 'newspapik' ),
				'description' => 'https://youtube.com/c/YouTubeCreators',
				'default'     => '',
			),
		);
	}

	public function sanitize_categories( $input ) {

		foreach ( $input as $value ) {
			if ( ! array_key_exists( $value, $this->categories ) ) {
				return [];
			}
		}

		return $input;
	}

	/**
	 * Main Class Instance.
	 *
	 * Ensures only one instance of this class is loaded or can be loaded.
	 *
	 * @static
	 * @return Newspapik_Theme_Options - Main instance.
	 */
	public static function get_instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}
}